@@ -1,6 +1,6 @@
 # /*##########################################################################
 #
-# Copyright (c) 2017-2023 European Synchrotron Radiation Facility
+# Copyright (c) 2017-2024 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -45,6 +45,7 @@ from ....utils.weakref import WeakList
 from .core import PointsBase, ColormapMixIn, ScatterVisualizationMixIn
 from .axis import Axis
 from ._pick import PickingResult
+from silx._utils import NP_OPTIONAL_COPY
 
 
 _logger = logging.getLogger(__name__)
@@ -236,7 +237,7 @@ def _quadrilateral_grid_coords(points):
 
 
 def _quadrilateral_grid_as_triangles(points):
-    """Returns the points and indices to make a grid of quadirlaterals
+    """Returns the points and indices to make a grid of quadrilaterals
 
     :param numpy.ndarray points:
         3D array of points (height, width, 2)
@@ -712,7 +713,7 @@ class Scatter(PointsBase, ColormapMixIn, ScatterVisualizationMixIn):
                         shape = shape[0], int(numpy.ceil(nbpoints / shape[0]))
 
                 if shape[0] < 2 or shape[1] < 2:  # Single line, at least 2 points
-                    points = numpy.ones((2, nbpoints, 2), dtype=numpy.float64)
+                    points = numpy.zeros((2, nbpoints, 3), dtype=numpy.float64)
                     # Use row/column major depending on shape, not on info value
                     gridOrder = "row" if shape[0] == 1 else "column"
 
@@ -726,19 +727,14 @@ class Scatter(PointsBase, ColormapMixIn, ScatterVisualizationMixIn):
                     # Add a second line that will be clipped in the end
                     points[1, :-1] = (
                         points[0, :-1]
-                        + numpy.cross(points[0, 1:] - points[0, :-1], (0.0, 0.0, 1.0))[
-                            :, :2
-                        ]
+                        + numpy.cross(points[0, 1:] - points[0, :-1], (0.0, 0.0, 1.0))
                     )
                     points[1, -1] = (
                         points[0, -1]
-                        + numpy.cross(points[0, -1] - points[0, -2], (0.0, 0.0, 1.0))[
-                            :2
-                        ]
+                        + numpy.cross(points[0, -1] - points[0, -2], (0.0, 0.0, 1.0))
                     )
 
-                    points.shape = 2, nbpoints, 2  # Use same shape for both orders
-                    coords, indices = _quadrilateral_grid_as_triangles(points)
+                    points = points[:, :, :2]
 
                 elif gridOrder == "row":  # row-major order
                     if nbpoints != numpy.prod(shape):
@@ -930,8 +926,8 @@ class Scatter(PointsBase, ColormapMixIn, ScatterVisualizationMixIn):
             )
         return self.__interpolatorFuture
 
-    def _logFilterData(self, xPositive, yPositive):
-        """Filter out values with x or y <= 0 on log axes
+    def _filterData(self, xPositive: bool, yPositive: bool):
+        """Filter out errors<0 and values with x or y <= 0 on log axes
 
         :param bool xPositive: True to filter arrays according to X coords.
         :param bool yPositive: True to filter arrays according to Y coords.
@@ -949,7 +945,7 @@ class Scatter(PointsBase, ColormapMixIn, ScatterVisualizationMixIn):
                 value = numpy.array(value, copy=True, dtype=numpy.float64)
                 value[clipped] = numpy.nan
 
-        x, y, xerror, yerror = PointsBase._logFilterData(self, xPositive, yPositive)
+        x, y, xerror, yerror = PointsBase._filterData(self, xPositive, yPositive)
 
         return x, y, value, xerror, yerror
 
@@ -960,7 +956,7 @@ class Scatter(PointsBase, ColormapMixIn, ScatterVisualizationMixIn):
                      False to use internal representation (do not modify!)
         :rtype: numpy.ndarray
         """
-        return numpy.array(self._value, copy=copy)
+        return numpy.array(self._value, copy=copy or NP_OPTIONAL_COPY)
 
     def getAlphaData(self, copy=True):
         """Returns the alpha (transparency) assigned to the scatter data points.
@@ -969,7 +965,7 @@ class Scatter(PointsBase, ColormapMixIn, ScatterVisualizationMixIn):
                      False to use internal representation (do not modify!)
         :rtype: numpy.ndarray
         """
-        return numpy.array(self.__alpha, copy=copy)
+        return numpy.array(self.__alpha, copy=copy or NP_OPTIONAL_COPY)
 
     def getData(self, copy=True, displayed=False):
         """Returns the x, y coordinates and the value of the data points
@@ -1018,7 +1014,7 @@ class Scatter(PointsBase, ColormapMixIn, ScatterVisualizationMixIn):
         :param bool copy: True make a copy of the data (default),
                           False to use provided arrays.
         """
-        value = numpy.array(value, copy=copy)
+        value = numpy.array(value, copy=copy or NP_OPTIONAL_COPY)
         assert value.ndim == 1
         assert len(x) == len(value)
 
@@ -1043,7 +1039,7 @@ class Scatter(PointsBase, ColormapMixIn, ScatterVisualizationMixIn):
 
         if alpha is not None:
             # Make sure alpha is an array of float in [0, 1]
-            alpha = numpy.array(alpha, copy=copy)
+            alpha = numpy.array(alpha, copy=copy or NP_OPTIONAL_COPY)
             assert alpha.ndim == 1
             assert len(x) == len(alpha)
             if alpha.dtype.kind != "f":
